Package: cpvSNP
Type: Package
Title: Gene set analysis methods for SNP association p-values that lie
        in genes in given gene sets
Version: 1.44.0
Date: 2021-11-20
Author: Caitlin McHugh, Jessica Larson, and Jason Hackney
Maintainer: Caitlin McHugh <mchughc@uw.edu>
Imports: methods, corpcor, BiocParallel, ggplot2, plyr
Depends: R (>= 3.5.0), GenomicFeatures, GSEABase (>= 1.24.0)
Suggests: TxDb.Hsapiens.UCSC.hg19.knownGene, RUnit, BiocGenerics,
        ReportingTools, BiocStyle
Description: Gene set analysis methods exist to combine SNP-level
        association p-values into gene sets, calculating a single
        association p-value for each gene set. This package implements
        two such methods that require only the calculated SNP p-values,
        the gene set(s) of interest, and a correlation matrix (if
        desired). One method (GLOSSI) requires independent SNPs and the
        other (VEGAS) can take into account correlation (LD) among the
        SNPs. Built-in plotting functions are available to help users
        visualize results.
License: Artistic-2.0
biocViews: Genetics, StatisticalMethod, Pathways, GeneSetEnrichment,
        GenomicVariation
git_url: https://git.bioconductor.org/packages/cpvSNP
git_branch: RELEASE_3_23
git_last_commit: 78868a5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:26:26 UTC; biocbuild
