import(GSEABase)
import(GenomicFeatures)
import(corpcor)
import(plyr)
import(BiocParallel)
import(ggplot2)
import(methods)

export(assocPvalBySetPlot)
export(createArrayData)
export(geneToSNPList)
export(glossi)
export(glossiMarginal)
export(plotPvals)
export(simulate_chisq)
export(vegas)
export(vegasMarginal)

exportClasses(GeneSetResult, GeneSetResultCollection, VEGASResult, VEGASResultCollection, GLOSSIResult, GLOSSIResultCollection)
exportMethods(geneSetName, pValue, simulatedStats, degreesOfFreedom, statistic)