setGeneric("geneSetName", function(object) standardGeneric("geneSetName") )

setGeneric("pValue", function(object) standardGeneric("pValue") )

setGeneric("simulatedStats", function(object) standardGeneric("simulatedStats") )

setGeneric("degreesOfFreedom", function(object) standardGeneric("degreesOfFreedom") )

setGeneric("statistic", function(object) standardGeneric("statistic") )