\name{summary-methods}
\docType{methods}
\alias{show}
\alias{show-methods}
\alias{show,VEGASResult-method}
\alias{show,GLOSSIResult-method}
\title{ ~~ Methods for Function \code{show} in Package \pkg{base} ~~}
\description{
 ~~ Methods for function \code{show} in package \pkg{base} ~~
}
\section{Methods}{
\describe{
 Defined methods include:
	\item{
		\code{signature(x = "VEGASResult")},
		\code{signature(x = "GLOSSIResult")}
		}{
			These methods display the corresponding statistics and p-values for the corresponding VEGAS or GLOSSI analysis.
		}
	}
}
\author{
Caitlin McHugh
}
\keyword{methods}
